# Tiber Logger for Tiber Health Innovations and Partners
Tiber Logger is a common logging routine used by Tiber Health Python projects to produce consistent and common logging between our scripts and applications. 

This tool was written and tested using Python 3.11. 
